@@ -1,4 +1,4 @@
-__version__ = '1.0.10'
+__version__ = '1.0.12'
 __author__ = 'arnold'
 
 import json
@@ -6,6 +6,7 @@ from multiprocessing import AuthenticationError
 import os
 import requests
 from urllib.parse import urljoin
+import posixpath
 
 from jinja2 import nodes
 from jinja2.ext import Extension
@@ -80,9 +81,10 @@ class TerraformQueryExtension(Extension):
         }
 
         # Getting the current state version outputs for the workspace.
-        TFC_URL = 'https://app.terraform.io/'
-        BASE_URL = urljoin(TFC_URL, "/api/v2")
-        WORKSPACE_PATH = "/organizations/{org_name}/workspaces/{workspace_name}"
+        BASE_URL = 'https://app.terraform.io/api/v2'
+        print(BASE_URL)
+        WORKSPACE_PATH = posixpath.join("organizations", org_name, "workspaces",workspace_name )
+        # WORKSPACE_PATH = f'organizations/{org_name}/workspaces/{workspace_name}'
         # workspace_url = f'{BASE_URL}/organizations/{org_name}/workspaces/{workspace_name}'
         workspace_url = urljoin(BASE_URL, WORKSPACE_PATH)
         s = requests.Session()
@@ -94,7 +96,8 @@ class TerraformQueryExtension(Extension):
             raise SystemExit(err)
         search_listed_ws = resp.json()
         ws_id = search_listed_ws['data']['id']
-        state_output_path = "/workspaces/{ws_id}/current-state-version-outputs"
+        # state_output_path = f'workspaces/{ws_id}/current-state-version-outputs'
+        state_output_path = posixpath.join("workspaces", ws_id, "current-state-version-outputs")
         state_output_url = urljoin(BASE_URL, state_output_path)
         try:
             resp = s.get(state_output_url)
